==> ejc-qualitymanagement-impl-3.0.0-20250908.090055-55-sources.jar: com/ejianc/business/safety/controller/FeedbackPlanController.java <==
package com.ejianc.business.safety.controller;

import java.io.Serializable;

import com.ejianc.business.safety.bean.EmergencyPlanDetailEntity;
import com.ejianc.business.safety.bean.EmergencyPlanEntity;
import com.ejianc.business.safety.bean.FeedbackPlanDetailEntity;
import com.ejianc.business.safety.service.IFeedbackPlanDetailService;
import com.ejianc.business.scene.vo.EmergencyPlanDetailVO;
import com.ejianc.business.scene.vo.FeedbackPlanDetailVO;
import com.ejianc.business.scene.vo.FeedbackPlanVO;
import com.ejianc.business.scene.vo.trainPlanVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.safety.bean.FeedbackPlanEntity;
import com.ejianc.business.safety.service.IFeedbackPlanService;


/**
 * 经验反馈计划
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("feedbackPlan")
public class FeedbackPlanController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "FEEDBACK-PLAN";//此处需要根据实际修改

    @Autowired
    private IFeedbackPlanService service;
    @Autowired
    private IFeedbackPlanDetailService feedbackPlanDetailService;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IFeedbackPlanDetailService detailService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<FeedbackPlanVO> saveOrUpdate(@RequestBody FeedbackPlanVO saveOrUpdateVO) {
    	FeedbackPlanEntity entity = BeanMapper.map(saveOrUpdateVO, FeedbackPlanEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	FeedbackPlanVO vo = BeanMapper.map(entity, FeedbackPlanVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FeedbackPlanVO> queryDetail(Long id) {
    	FeedbackPlanEntity entity = service.selectById(id);
    	FeedbackPlanVO vo = BeanMapper.map(entity, FeedbackPlanVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<FeedbackPlanVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (FeedbackPlanVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(FeedbackPlanVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<FeedbackPlanVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("unitName");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("billCode");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        IPage<FeedbackPlanEntity> page = service.queryPage(param,false);
        IPage<FeedbackPlanVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), FeedbackPlanVO.class));
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * @Description queryList 台账
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryTZList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<FeedbackPlanDetailVO>> queryTZList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("unitName");


        param.getFuzzyFields().add("feedbackContent");
        param.getFuzzyFields().add("feedbackObject");

        /** 租户隔离 */
        queryParam.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        queryParam.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        queryParam.getParams().put("billState",new Parameter(QueryParam.IN,Arrays.asList(1,3)));
        List<FeedbackPlanEntity> trainPlanEntityList = service.queryList(queryParam);
        if (!CollectionUtils.isEmpty(trainPlanEntityList)&&trainPlanEntityList.size()>0) {
            List<Long> ids = trainPlanEntityList.stream().map(FeedbackPlanEntity::getId).collect(Collectors.toList());
            Map<Long, String> projectName = trainPlanEntityList.stream().collect(Collectors.toMap(FeedbackPlanEntity::getId, FeedbackPlanEntity::getProjectName));
            Map<Long, String> unitName = trainPlanEntityList.stream().collect(Collectors.toMap(FeedbackPlanEntity::getId, FeedbackPlanEntity::getUnitName));
            param.getParams().put("pid", new Parameter(QueryParam.IN, ids));
            IPage<FeedbackPlanDetailEntity> page = detailService.queryPage(param, false);
            List<FeedbackPlanDetailVO> voList = BeanMapper.mapList(page.getRecords(), FeedbackPlanDetailVO.class);
            voList.forEach(e -> {
                e.setProjectName(projectName.get(e.getPid()));
                e.setUnitName(unitName.get(e.getPid()));
            });
            IPage<FeedbackPlanDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
            pageData.setRecords(voList);
            return CommonResponse.success("查询列表数据成功！", pageData);
        }
        return CommonResponse.success("查询列表数据成功！",null);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<FeedbackPlanEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        List<FeedbackPlanVO> voList = BeanMapper.mapList(list, FeedbackPlanVO.class);
        voList.forEach(e -> {
            e.setBillStateName(BillStateEnum.getEnumByStateCode(e.getBillState()).getDescription());
        });
        beans.put("records", voList);
        ExcelExport.getInstance().export("FeedbackPlan-export.xlsx", beans, response);
    }
    /**
     * @Description 台账导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelTZExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelTZExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        QueryParam queryParam = new QueryParam();
        /** 租户隔离 */
        queryParam.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        queryParam.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<FeedbackPlanEntity> trainPlanEntityList = service.queryList(queryParam);

        List<Long> ids = trainPlanEntityList.stream().map(FeedbackPlanEntity::getId).collect(Collectors.toList());
        Map<Long,String> projectName=trainPlanEntityList.stream().collect(Collectors.toMap(FeedbackPlanEntity::getId,FeedbackPlanEntity::getProjectName));
        Map<Long,String> unitName=trainPlanEntityList.stream().collect(Collectors.toMap(FeedbackPlanEntity::getId,FeedbackPlanEntity::getUnitName));
        param.getParams().put("pid",new Parameter(QueryParam.IN,ids));
        IPage<FeedbackPlanDetailEntity> page = detailService.queryPage(param, false);
        List<FeedbackPlanDetailVO> voList = BeanMapper.mapList(page.getRecords(), FeedbackPlanDetailVO.class);
        voList.forEach(e -> {
            e.setProjectName(projectName.get(e.getPid()));
            e.setUnitName(unitName.get(e.getPid()));
        });
        IPage<FeedbackPlanDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(voList); Map<String, Object> beans = new HashMap<>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("FeedbackPlanTZ-export.xlsx", beans, response);
    }
    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refFeedbackPlanData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FeedbackPlanVO>> refFeedbackPlanData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<FeedbackPlanEntity> page = service.queryPage(param,false);
        IPage<FeedbackPlanVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FeedbackPlanVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-qualitymanagement-impl-3.0.0-20250911.030535-58-sources.jar: com/ejianc/business/safety/controller/FeedbackPlanController.java <==
package com.ejianc.business.safety.controller;

import java.io.Serializable;

import com.ejianc.business.safety.bean.EmergencyPlanDetailEntity;
import com.ejianc.business.safety.bean.EmergencyPlanEntity;
import com.ejianc.business.safety.bean.FeedbackPlanDetailEntity;
import com.ejianc.business.safety.service.IFeedbackPlanDetailService;
import com.ejianc.business.scene.vo.EmergencyPlanDetailVO;
import com.ejianc.business.scene.vo.FeedbackPlanDetailVO;
import com.ejianc.business.scene.vo.FeedbackPlanVO;
import com.ejianc.business.scene.vo.trainPlanVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.safety.bean.FeedbackPlanEntity;
import com.ejianc.business.safety.service.IFeedbackPlanService;


/**
 * 经验反馈计划
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("feedbackPlan")
public class FeedbackPlanController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "FEEDBACK-PLAN";//此处需要根据实际修改

    @Autowired
    private IFeedbackPlanService service;
    @Autowired
    private IFeedbackPlanDetailService feedbackPlanDetailService;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IFeedbackPlanDetailService detailService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<FeedbackPlanVO> saveOrUpdate(@RequestBody FeedbackPlanVO saveOrUpdateVO) {
    	FeedbackPlanEntity entity = BeanMapper.map(saveOrUpdateVO, FeedbackPlanEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	FeedbackPlanVO vo = BeanMapper.map(entity, FeedbackPlanVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FeedbackPlanVO> queryDetail(Long id) {
    	FeedbackPlanEntity entity = service.selectById(id);
    	FeedbackPlanVO vo = BeanMapper.map(entity, FeedbackPlanVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<FeedbackPlanVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (FeedbackPlanVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(FeedbackPlanVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<FeedbackPlanVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("unitName");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("billCode");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        IPage<FeedbackPlanEntity> page = service.queryPage(param,false);
        IPage<FeedbackPlanVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), FeedbackPlanVO.class));
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * @Description queryList 台账
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryTZList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<FeedbackPlanDetailVO>> queryTZList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("unitName");


        param.getFuzzyFields().add("feedbackContent");
        param.getFuzzyFields().add("feedbackObject");

        /** 租户隔离 */
        queryParam.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        queryParam.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        queryParam.getParams().put("billState",new Parameter(QueryParam.IN,Arrays.asList(1,3)));
        List<FeedbackPlanEntity> trainPlanEntityList = service.queryList(queryParam);
        if (!CollectionUtils.isEmpty(trainPlanEntityList)&&trainPlanEntityList.size()>0) {
            List<Long> ids = trainPlanEntityList.stream().map(FeedbackPlanEntity::getId).collect(Collectors.toList());
            Map<Long, String> projectName = trainPlanEntityList.stream().collect(Collectors.toMap(FeedbackPlanEntity::getId, FeedbackPlanEntity::getProjectName));
            Map<Long, String> unitName = trainPlanEntityList.stream().collect(Collectors.toMap(FeedbackPlanEntity::getId, FeedbackPlanEntity::getUnitName));
            param.getParams().put("pid", new Parameter(QueryParam.IN, ids));
            IPage<FeedbackPlanDetailEntity> page = detailService.queryPage(param, false);
            List<FeedbackPlanDetailVO> voList = BeanMapper.mapList(page.getRecords(), FeedbackPlanDetailVO.class);
            voList.forEach(e -> {
                e.setProjectName(projectName.get(e.getPid()));
                e.setUnitName(unitName.get(e.getPid()));
            });
            IPage<FeedbackPlanDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
            pageData.setRecords(voList);
            return CommonResponse.success("查询列表数据成功！", pageData);
        }
        return CommonResponse.success("查询列表数据成功！",null);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<FeedbackPlanEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        List<FeedbackPlanVO> voList = BeanMapper.mapList(list, FeedbackPlanVO.class);
        voList.forEach(e -> {
            e.setBillStateName(BillStateEnum.getEnumByStateCode(e.getBillState()).getDescription());
        });
        beans.put("records", voList);
        ExcelExport.getInstance().export("FeedbackPlan-export.xlsx", beans, response);
    }
    /**
     * @Description 台账导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelTZExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelTZExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        QueryParam queryParam = new QueryParam();
        /** 租户隔离 */
        queryParam.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        queryParam.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<FeedbackPlanEntity> trainPlanEntityList = service.queryList(queryParam);

        List<Long> ids = trainPlanEntityList.stream().map(FeedbackPlanEntity::getId).collect(Collectors.toList());
        Map<Long,String> projectName=trainPlanEntityList.stream().collect(Collectors.toMap(FeedbackPlanEntity::getId,FeedbackPlanEntity::getProjectName));
        Map<Long,String> unitName=trainPlanEntityList.stream().collect(Collectors.toMap(FeedbackPlanEntity::getId,FeedbackPlanEntity::getUnitName));
        param.getParams().put("pid",new Parameter(QueryParam.IN,ids));
        IPage<FeedbackPlanDetailEntity> page = detailService.queryPage(param, false);
        List<FeedbackPlanDetailVO> voList = BeanMapper.mapList(page.getRecords(), FeedbackPlanDetailVO.class);
        voList.forEach(e -> {
            e.setProjectName(projectName.get(e.getPid()));
            e.setUnitName(unitName.get(e.getPid()));
        });
        IPage<FeedbackPlanDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(voList);
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("FeedbackPlanTZ-X-export.xlsx", beans, response);
    }
    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refFeedbackPlanData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FeedbackPlanVO>> refFeedbackPlanData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<FeedbackPlanEntity> page = service.queryPage(param,false);
        IPage<FeedbackPlanVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FeedbackPlanVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
